@@ -8,7 +8,8 @@ clvarselgrbkw <- function(X, G = 1:9,
                           samp = FALSE, sampsize = 2000, 
                           hcModel = "VVV", allow.EEE = TRUE, forcetwo = TRUE, 
                           BIC.diff = 0, itermax = 100,
-                          parallel = FALSE, verbose = FALSE)
+                          parallel = FALSE, 
+                          verbose = interactive())
 {
 
   X <- as.matrix(X)
